@@ -1,6 +1,6 @@
 package Workflow;
 
-# $Id: Workflow.pm,v 1.31 2006/12/14 08:08:54 jonasbn Exp $
+# $Id: Workflow.pm,v 1.32 2006/12/14 08:18:15 jonasbn Exp $
 
 use strict;
 
@@ -13,7 +13,7 @@ use Workflow::Factory   qw( FACTORY );
 my @FIELDS = qw( id type description state last_update );
 __PACKAGE__->mk_accessors( @FIELDS );
 
-$Workflow::VERSION  = sprintf("%d.%02d", q$Revision: 1.31 $ =~ /(\d+)\.(\d+)/);
+$Workflow::VERSION  = sprintf("%d.%02d", q$Revision: 1.32 $ =~ /(\d+)\.(\d+)/);
 
 use constant NO_CHANGE_VALUE => 'NOCHANGE';
 
@@ -342,7 +342,7 @@ Workflow - Simple, flexible system to implement workflows
          <action name="upload file" resulting_state="uploaded" />
      </state>
      <state name="uploaded" autorun="yes">
-         <action name="verify file" resulting_state="annotate">
+         <action name="verify file" resulting_state="verified file">
               <!-- everyone other than 'CWINTERS' must verify -->
               <condition test="$context->{user} ne 'CWINTERS'" />
          </action>
@@ -350,10 +350,13 @@ Workflow - Simple, flexible system to implement workflows
               <condition test="$context->{user} eq 'CWINTERS'" />
          </action>
      </state>
-     <state name="verify file">
+     <state name="verified file">
          <action name="annotate">
              <condition name="can_annotate" />
          </action>
+         <action name="null">
+             <condition name="!can_annotate" />
+         </action>
      </state>
      <state name="annotated" autorun="yes" may_stop="yes">
          <action name="null" resulting_state="finished">
@@ -1022,7 +1025,7 @@ Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
 The following folks have also helped out:
 
-Alexander Klink, for: patch resulting in 0.23 and 0.24
+Alexander Klink, for: patches resulting in 0.23, 0.24 and 0.25
 
 Michael Bell, for patch resulting in 0.22
 
