@@ -1,6 +1,6 @@
 package Workflow::Action;
 
-# $Id: Action.pm,v 1.6 2004/10/11 22:22:26 cwinters Exp $
+# $Id: Action.pm,v 1.9 2006/08/18 21:29:16 jonasbn Exp $
 
 # Note: we may implement a separate event mechanism so that actions
 # can trigger other code (use 'Class::Observable'? read observations
@@ -10,9 +10,10 @@ use strict;
 use base qw( Workflow::Base );
 use Log::Log4perl     qw( get_logger );
 use Workflow::Action::InputField;
+use Workflow::Validator::HasRequiredField;
 use Workflow::Factory qw( FACTORY );
 
-$Workflow::Action::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Action::VERSION  = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class description );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -27,12 +28,12 @@ sub add_fields {
 
 sub required_fields {
     my ( $self ) = @_;
-    return grep { $_->{type} eq 'required' } @{ $self->{_fields} };
+    return grep { $_->requirement() eq 'required' } @{ $self->{_fields} };
 }
 
 sub optional_fields {
     my ( $self ) = @_;
-    return grep { $_->{type} eq 'optional' } @{ $self->{_fields} };
+    return grep { $_->requirement() eq 'optional' } @{ $self->{_fields} };
 }
 
 sub fields {
@@ -102,11 +103,31 @@ sub init {
     $self->name( $copy_params{name} );
     $self->description( $copy_params{description} );
 
+    ## init normal fields
     my @fields = $self->normalize_array( $copy_params{field} );
     foreach my $field_info ( @fields ) {
         $self->add_fields( Workflow::Action::InputField->new( $field_info ) );
     }
 
+    ## establish validator for fields with is_required="yes"
+    @fields = $self->required_fields();
+    my $validator = Workflow::Validator::HasRequiredField->new (
+                    {
+                        name  => 'HasRequiredField for is_required fields',
+                        class => 'Workflow::Validator::HasRequiredField'
+                    });
+    my @args = ();
+    foreach my $field ( @fields ) {
+        next if (not $field); ## empty @fields array
+        push @args, $field->name();
+    }
+    push @{ $self->{_validators} },
+         {
+             validator => $validator,
+             args      => \@args
+         };
+
+    ## init normal validators
     my @validator_info = $self->normalize_array( $copy_params{validator} );
     $self->add_validators( @validator_info );
 
@@ -187,31 +208,31 @@ use it as such but it is strongly recommended.
 
 =head2 Public Methods
 
-B<add_field( @fields )>
+=head3 add_field( @fields )
 
 Add one or more L<Workflow::Action::InputField>s to the action.
 
-B<required_fields()>
+=head3 required_fields()
 
 Return a list of L<Workflow::Action::InputField> objects that are required.
 
-B<optional_fields()>
+=head3 optional_fields()
 
 Return a list of L<Workflow::Action::InputField> objects that are optional.
 
-B<fields()>
+=head3 fields()
 
 Return a list of all L<Workflow::Action::InputField> objects
 associated with this action.
 
-B<add_validators( @validator_config )>
+=head3 add_validators( @validator_config )
 
 Given the 'validator' configuration declarations in the action
 configuration, ask the L<Workflow::Factory> for the
 L<Workflow::Validator> object associated with each name and store that
 along with the arguments to be used, runtime and otherwise.
 
-B<get_validators()>
+=head3 get_validators()
 
 Get a list of all the validator hashrefs, each with two keys:
 'validator' and 'args'. The 'validator' key contains the appropriate
@@ -219,21 +240,23 @@ L<Workflow::Validator> object, while 'args' contains an arrayref of
 arguments to pass to the validator, some of which may need to be
 evaluated at runtime.
 
-B<validate( $workflow )>
+=head3 validate( $workflow )
 
 Run through all validators for this action. If any fail they will
 throw a L<Workflow::Exception>, the validation subclass.
 
-B<execute( $workflow )>
+=head3 execute( $workflow )
 
 Subclasses B<must> implement -- this will perform the actual
 work. It's not required that you return anything, but if the action
 may be used in a L<Workflow::State> object that has multiple resulting
 states you should return a simple scalar for a return value.
 
+#=head3 add_fields
+
 =head2 Private Methods
 
-B<init( $workflow, \%params )>
+#=head3 init( $workflow, \%params )
 
 =head1 SEE ALSO
 
