@@ -1,11 +1,11 @@
 package Workflow::Condition;
 
-# $Id: Condition.pm,v 1.6 2006/09/12 17:59:30 jonasbn Exp $
+# $Id: Condition.pm,v 1.7 2006/12/14 08:18:15 jonasbn Exp $
 
 use strict;
 use base qw( Workflow::Base );
 
-$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -49,10 +49,18 @@ Workflow::Condition - Evaluate a condition depending on the workflow state and e
  <workflow>
    <state>
      ...
-     <action name="MyAction">
+     <action name="SomeAdminAction">
        ... 
        <condition name="IsAdminUser" />
      </action>
+     <action name="AnotherAdminAction">
+      ...
+      <condition name="IsAdminUser" />
+     </action>
+     <action name="AUserAction">
+      ...
+      <condition name="!IsAdminUser" />
+     </action>
    </state>
    ...
  </workflow>
@@ -147,6 +155,24 @@ condition from the C<$workflow> object.
 
 #=head3 init
 
+=head2 Caching and inverting the result
+
+If in one state, you ask for the same condition again, Workflow uses
+the cached result, so that within one list of available actions, you
+will get a consistent view. Note that if we would not use caching,
+this might not necessary be the case, as something external might
+change between the two evaluate() calls.
+
+Caching is also used with an inverted condition, which you can specify
+in the definition using C<<condition name="!some_condition">>.
+This condition returns exactly the opposite of the original one, i.e.
+if the original condition fails, this one does not and the other way
+round. As caching is used, you can model "yes/no" decisions using this
+feature - if you have both C<<condition name="some_condition">> and
+C<<condition name="!some_condition">> in your workflow state definition,
+exactly one of them will succeed and one will fail - which is particularly
+useful if you use "autorun" a lot.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003-2004 Chris Winters. All rights reserved.
